scipy.maxentropy.maxentropy
===========================

.. automodule:: scipy.maxentropy.maxentropy

   
   
   .. rubric:: Functions

   .. autosummary::
   
      arrayexp
      asarray
      columnmeans
      columnvariances
      flatten
      innerprod
      innerprodtranspose
      logsumexp
      norm
      sparsefeaturematrix
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      basemodel
      bigmodel
      conditionalmodel
      model
   
   

   
   
   .. rubric:: Exceptions

   .. autosummary::
   
      DivergenceError
   
   